summaryrefslogtreecommitdiff
path: root/include/http_config.h
diff options
context:
space:
mode:
authorJeff Trawick <trawick@apache.org>2009-03-30 11:27:53 +0000
committerJeff Trawick <trawick@apache.org>2009-03-30 11:27:53 +0000
commitfb6a306876ee8265da71c7a0bd69eb0040a04e84 (patch)
treeb15caef08dd680e3145eb0686b6ae8be9b37c876 /include/http_config.h
parent772241ef6873603c9b28458c0120ef58ea2fe4c4 (diff)
downloadhttpd-fb6a306876ee8265da71c7a0bd69eb0040a04e84.tar.gz
rename the new retained-data APIs to ap_retained_data_create()/ap_retained_data_get(), for better
consistency with existing APIs (e.g., slotmem) don't bother changing the MMN, which doesn't reflect recent -dev changes anyway git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@759924 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/http_config.h')
-rw-r--r--include/http_config.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/http_config.h b/include/http_config.h
index 6ad9087046..a140fb7cb8 100644
--- a/include/http_config.h
+++ b/include/http_config.h
@@ -921,14 +921,14 @@ AP_DECLARE(int) ap_process_config_tree(server_rec *s,
* @param Size in bytes of the retained data (to be allocated)
* @return Address of new retained data structure, initially cleared
*/
-AP_DECLARE(void *) ap_set_retained_data(const char *key, apr_size_t size);
+AP_DECLARE(void *) ap_retained_data_create(const char *key, apr_size_t size);
/**
* Retrieve data which was stored by ap_set_retained_data()
* @param key The unique key associated with this module's retained data
* @return Address of previously retained data structure, or NULL if not yet saved
*/
-AP_DECLARE(void *) ap_get_retained_data(const char *key);
+AP_DECLARE(void *) ap_retained_data_get(const char *key);
/* Module-method dispatchers, also for http_request.c */
/**
@@ -921,14 +921,14 @@ AP_DECLARE(int) ap_process_config_tree(server_rec *s,
/**
- * Retrieve data which was stored by ap_set_retained_data()
+ * Retrieve data which was stored by ap_retained_data_create()
* @param key The unique key associated with this module's retained data
* @return Address of previously retained data structure, or NULL if not yet saved